Module error

Module error 

Error types for byte buffer operations.

Structs

InvalidIntegerLength
Error type indicating an invalid integer length was specified. This is used when attempting to read or write an integer with an invalid number of bytes.
OutOfBounds
Error type indicating an index or range is out of bounds.
RangeOutOfBounds
Error type indicating an index or range is out of bounds.
TryGetErroralloc or std
Error type for the try_get_ methods of Buf. Indicates that there were not enough remaining bytes in the buffer while attempting to get a value from a Buf with one of the try_get_ methods.
TryPutError
Error type for the try_put_ methods of crate::Buffer. Indicates that there were not enough remaining capacity in the buffer while attempting to put a value to a crate::Buffer with one of the try_put_ methods.

Enums

FromBytesError
Error type for converting a raw byte slice into a fixed-capacity UTF-8 buffer. Combines UTF-8 validation and capacity errors.
TryPutIntegerError
Error type for the try_put_ methods of crate::Buffer. Indicates that there were not enough remaining capacity in the buffer while attempting to put a value to a crate::Buffer with one of the try_put_ methods.
Utf8Error
Error type for UTF-8 operations that indicates an invalid character boundary or out of bounds access.