Error types for byte buffer operations.
Structs
- Invalid
Integer Length - Error type indicating an invalid integer length was specified. This is used when attempting to read or write an integer with an invalid number of bytes.
- OutOf
Bounds - Error type indicating an index or range is out of bounds.
- Range
OutOf Bounds - Error type indicating an index or range is out of bounds.
- TryGet
Error allocorstd - Error type for the
try_get_methods ofBuf. Indicates that there were not enough remaining bytes in the buffer while attempting to get a value from aBufwith one of thetry_get_methods. - TryPut
Error - Error type for the
try_put_methods ofcrate::Buffer. Indicates that there were not enough remaining capacity in the buffer while attempting to put a value to acrate::Bufferwith one of thetry_put_methods.
Enums
- From
Bytes Error - Error type for converting a raw byte slice into a fixed-capacity UTF-8 buffer. Combines UTF-8 validation and capacity errors.
- TryPut
Integer Error - Error type for the
try_put_methods ofcrate::Buffer. Indicates that there were not enough remaining capacity in the buffer while attempting to put a value to acrate::Bufferwith one of thetry_put_methods. - Utf8
Error - Error type for UTF-8 operations that indicates an invalid character boundary or out of bounds access.